# Keras models


::: ceruleo.models.keras.catalog.CNLSTM

::: ceruleo.models.keras.catalog.InceptionTime

::: ceruleo.models.keras.catalog.MSWRLRCN

::: ceruleo.models.keras.catalog.MultiScaleConvolutional

::: ceruleo.models.keras.catalog.MVCNN

::: ceruleo.models.keras.catalog.XiangQiangJianQiao

::: ceruleo.models.keras.catalog.XCM


